@@ -1,5 +1,5 @@
 
-.First.lib <- function(lib, pkg) {
+.onLoad <- function(lib, pkg) {
       library.dynam("boolfun", pkg, lib)
 }
 
